Procedural macros for the Sails framework.
Attribute Macros
- event
- Defines event for using within Gear and Ethereum ecosystem.
- export
- Customizes how a service/program method is exposed based on specified arguments.
- program
- Generates code for turning a Rust impl block into a Sails program based on a set of public methods of the block. See documentation for details.
- sails_
type - Derives the canonical Sails type bundle:
Encode,Decode,TypeInfo, andReflectHash, together with theircrate =helper attributes routed to thesails_rsre-exports. - service
- Generates code for turning a Rust impl block into a Sails service based on a set of public methods of the block. See documentation for details.